==> libbft_1.0.8.orig.tar.gz: bft-1.0.8/src/bft_fp_trap.h <==
#ifndef __BFT_FP_TRAP_H__
#define __BFT_FP_TRAP_H__

/*============================================================================
 * Trap floating-point exceptions on some systems
 *============================================================================*/

/*
  This file is part of the "Base Functions and Types" library, intended to
  simplify and enhance portability, memory and I/O use for scientific codes.

  Copyright (C) 2004  EDF

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/*-----------------------------------------------------------------------------*/

/* Standard C library headers */

/* BFT library headers */

#include "bft_config.h"

/*-----------------------------------------------------------------------------*/

#ifdef __cplusplus
extern "C" {
#if 0
} /* Fake brace to force Emacs auto-indentation back to column 0 */
#endif
#endif /* __cplusplus */

/*============================================================================
 * Public types
 *============================================================================*/

/*============================================================================
 * Public function prototypes
 *============================================================================*/

/*
 * Enable trapping of floating point exceptions if possible.
 *
 * This function is currently implemented only on X86 and X86-64
 * type architectures running Linux, with BFT compiled with GCC,
 * and does nothing in other cases.
 *
 * On some system variants, some system calls have been seen to throw
 * floating-point exceptions in unexpected cases. For example:
 *
 * - Using the Electric Fence malloc() library under SuSE Linux 8.0,
 *   certain functions such as mktime() or atof() would throw a
 *   floating-point exception under the GDB debugger, but not on a simple
 *   (single-threaded) program run. This problem disappeared on
 *   SuSE Linux 8.1, and has not been encountered since.
 *
 * - Reading a file with libxml2 2.2.6 under Debian Linux 2.2 (and
 *   possibly other variants) throws floating-point exceptions.
 */

void
bft_fp_trap_set(void);

/*
 * Revert to initial enable trapping behavior of floating point
 * exceptions if possible.
 *
 * This function is currently implemented only on X86 and X86-64
 * type architectures running Linux, with BFT compiled with GCC,
 * and does nothing in other cases.
 */

void
bft_fp_trap_unset(void);

/*----------------------------------------------------------------------------*/

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __BFT_FP_TRAP_H__ */

==> libbft_1.1.2.orig.tar.gz: bft-1.1.2/src/bft_fp_trap.h <==
#ifndef __BFT_FP_TRAP_H__
#define __BFT_FP_TRAP_H__

/*============================================================================
 * Trap floating-point exceptions on some systems
 *============================================================================*/

/*
  This file is part of the "Base Functions and Types" library, intended to
  simplify and enhance portability, memory and I/O use for scientific codes.

  Copyright (C) 2004  EDF

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/*-----------------------------------------------------------------------------*/

/* Standard C library headers */

/* BFT library headers */

#include "bft_config.h"

/*-----------------------------------------------------------------------------*/

#ifdef __cplusplus
extern "C" {
#if 0
} /* Fake brace to force Emacs auto-indentation back to column 0 */
#endif
#endif /* __cplusplus */

/*============================================================================
 * Public types
 *============================================================================*/

/*============================================================================
 * Public function prototypes
 *============================================================================*/

/*
 * Enable trapping of floating point exceptions if possible.
 *
 * This function is deprecated, and does nothing.
 * Use C99's feenableexcept() instead.
 */

void
bft_fp_trap_set(void);

/*
 * Revert to initial enable trapping behavior of floating point
 * exceptions if possible.
 *
 * This function is deprecated, and does nothing.
 */

void
bft_fp_trap_unset(void);

/*----------------------------------------------------------------------------*/

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __BFT_FP_TRAP_H__ */
